<?php
/**
 * Theme Functions.
 */

function lz_food_recipee_setup() {
	
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-background', $defaults = array(
    'default-color'          => '',
    'default-image'          => '',
    'default-repeat'         => '',
    'default-position-x'     => '',
    'default-attachment'     => '',
    'wp-head-callback'       => '_custom_background_cb',
    'admin-head-callback'    => '',
    'admin-preview-callback' => ''
	));

	$GLOBALS['content_width'] = 525;

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', lzrestaurant_fonts_url() ) );
}
add_action( 'after_setup_theme', 'lz_food_recipee_setup' );

add_action( 'wp_enqueue_scripts', 'lz_food_recipee_enqueue_scripts' );

function lz_food_recipee_enqueue_scripts() {
	$parent_style = 'lzrestaurant-basic-style'; // Style handle of parent theme.
	wp_enqueue_style( $parent_style, esc_url(get_template_directory_uri()) . '/style.css' );
	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()).'/assets/css/bootstrap.css' );
	wp_enqueue_style( 'lz-food-recipee-basic-style', get_stylesheet_uri(), array( $parent_style ) );
	wp_enqueue_style( 'lz-food-recipee-font', lz_food_recipee_fonts_url(), array() );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	$custom_css = '';

	$lz_food_recipee_menu_section_padding = get_theme_mod('lz_food_recipee_menu_section_padding');
	$lz_food_recipee_menu_img_size = get_theme_mod('lz_food_recipee_menu_img_size');

	$custom_css = '
		#restaurant_menu {
			padding-top: '.esc_attr($lz_food_recipee_menu_section_padding).'px ;
			padding-bottom: '.esc_attr($lz_food_recipee_menu_section_padding).'px;
		}

		.service-img img {
			width: '.esc_attr($lz_food_recipee_menu_img_size).'px !important;
			height: '.esc_attr($lz_food_recipee_menu_img_size).'px !important;
		}
	';
	wp_add_inline_style( 'lz-food-recipee-basic-style',$custom_css );
}

add_action( 'init', 'lz_food_recipee_remove_parent_function'); 

function lz_food_recipee_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'lz-food-recipee' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 2', 'lz-food-recipee' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'lz-food-recipee' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'lz-food-recipee' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'lz-food-recipee' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'lz-food-recipee' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'lz-food-recipee' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'lz-food-recipee' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'lz_food_recipee_widgets_init' );

function lz_food_recipee_remove_parent_function() { 
	remove_action( 'admin_notices', 'lzrestaurant_activation_notice' ); 
	remove_action( 'admin_menu', 'lzrestaurant_gettingstarted' ); 
}

function lz_food_recipee_customize_register() {
	global $wp_customize;
	$wp_customize->remove_setting( 'display_header_text' );
	$wp_customize->remove_control( 'display_header_text' );		
}
add_action( 'customize_register', 'lz_food_recipee_customize_register');

// Customizer Section
function lz_food_recipee_customizer ( $wp_customize ) {
	$wp_customize->add_section('lz_food_recipee_service',array(
		'title'	=> __('Restaurant Menu','lz-food-recipee'),
		'panel' => 'lzrestaurant_panel_id',
	));

	$wp_customize->add_setting('lz_food_recipee_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('lz_food_recipee_title',array(
		'label'	=> __('Section Title','lz-food-recipee'),
		'section'	=> 'lz_food_recipee_service',
		'setting'	=> 'lz_food_recipee_title',
		'type'		=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('lz_food_recipee_category_setting',array(
		'default'	=> 'select',
		'sanitize_callback' => 'lz_food_recipee_sanitize_choices',
	));
	$wp_customize->add_control('lz_food_recipee_category_setting',array(
		'type'    => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Post','lz-food-recipee'),
		'section' => 'lz_food_recipee_service',
	));

	$wp_customize->add_setting('lz_food_recipee_menu_img_size',array(
		'default' => '',
		'sanitize_callback'	=> 'lzrestaurant_sanitize_float'
	));
	$wp_customize->add_control('lz_food_recipee_menu_img_size',array(
		'type' => 'number',
		'label' => __('Image Size','lz-food-recipee'),
		'section' => 'lz_food_recipee_service',
	));

	$wp_customize->add_setting('lz_food_recipee_menu_section_padding',array(
      'default' => '',
      'sanitize_callback'	=> 'lzrestaurant_sanitize_float'
	));
	$wp_customize->add_control('lz_food_recipee_menu_section_padding',array(
		'type' => 'number',
		'label' => __('Section Top Bottom Padding','lz-food-recipee'),
		'section' => 'lz_food_recipee_service',
	));
}
add_action( 'customize_register', 'lz_food_recipee_customizer' );

function lz_food_recipee_fonts_url(){
	$font_families = array(
		'Kaushan+Script',
		'Oswald:wght@200;300;400;500;600;700'
	);

	$fonts_url = add_query_arg( array(
		'family' => implode( '&family=', $font_families ),
		'display' => 'swap',
	), 'https://fonts.googleapis.com/css2' );

	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
	return $contents;
}

/*radio button sanitization*/
function lz_food_recipee_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

define('LZ_FOOD_RECIPEE_CREDIT',__('https://www.luzuk.com/top/wordpress-themes/restaurant/','lz-food-recipee'));

if ( ! function_exists( 'lz_food_recipee_credit' ) ) {
	function lz_food_recipee_credit(){
		echo "<a href=".esc_url(LZ_FOOD_RECIPEE_CREDIT)." target='_blank' >". esc_html__('Copyright © 2024 Restaurant WordPress Themes. All rights reserved.','lz-food-recipee') ."</a>";
	}
}

// Customizer Pro
require_once( ABSPATH . WPINC . '/class-wp-customize-section.php' );

class LZ_Food_Recipee_Customize_Section_Pro extends WP_Customize_Section {
	public $type = 'lz-food-recipee';
	public $pro_text = '';
	public $pro_url = '';
	public function json() {
		$json = parent::json();
		$json['pro_text'] = $this->pro_text;
		$json['pro_url']  = esc_url( $this->pro_url );
		return $json;
	}
	protected function render_template() { ?>
		<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
			<h3 class="accordion-section-title">
				{{ data.title }}
				<# if ( data.pro_text && data.pro_url ) { #>
					<a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
				<# } #>
			</h3>
		</li>
	<?php }
}

final class LZ_Food_Recipee_Customize {
	public static function get_instance() {
		static $instance = null;
		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}
		return $instance;
	}
	private function __construct() {}
	private function setup_actions() {
		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );
		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}
	public function sections( $manager ) {
		// Register custom section types.
		$manager->register_section_type( 'LZ_Food_Recipee_Customize_Section_Pro' );
		// Register sections.
		$manager->add_section( new LZ_Food_Recipee_Customize_Section_Pro( $manager, 'lz_food_recipee',
		array(
			'priority'   => 1,
			'title'    => esc_html__( 'Food Recipe Pro', 'lz-food-recipee' ),
			'pro_text' => esc_html__( 'Go Pro', 'lz-food-recipee' ),
			'pro_url'  => esc_url('https://www.luzuk.com/product/wordpress-recipe-theme/'),
		) ) );
	}
	public function enqueue_control_scripts() {
		wp_enqueue_script( 'lz-food-recipee-customize-controls', get_stylesheet_directory_uri() . '/js/child-customize-controls.js', array( 'customize-controls' ) );
		wp_enqueue_style( 'lz-food-recipee-customize-controls', get_stylesheet_directory_uri() . '/css/child-customize-controls.css' );
	}
}
LZ_Food_Recipee_Customize::get_instance();

function lz_food_recipee_customizer_js() {
    // Enqueue the customizer script
    wp_enqueue_script( 'lz_food_recipee-customizer-js', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-controls' ), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'lz_food_recipee_customizer_js' );